const path = require('path');

const env = process.env.BABEL_ENV || process.env.NODE_ENV;
module.exports = function(context, opts) {
  opts = opts || {};

  const envOpts = {
    debug: false,
    modules: false,
    // useBuiltIns: true,
    exclude: ['transform-regenerator', 'transform-async-to-generator'],
  };
  if (!opts['preset-env']) {
    envOpts.targets = {
      uglify: true,
      browsers: ['> .5% in US', 'last 1 versions'],
    }
  }
  return {
    presets: [
      [require.resolve('babel-preset-env'), Object.assign({}, envOpts, opts['preset-env'] || {})],
      require.resolve('babel-preset-react'),
    ],
    plugins: [
      require.resolve('babel-plugin-syntax-flow'),
      require.resolve('babel-plugin-syntax-dynamic-import'),
      [
        require.resolve('fast-async'),
        {
          spec: true,
        },
      ],
      // class { handleClick = () => { } }
      [
        require.resolve('babel-plugin-transform-class-properties'),
        {
          spec: true,
        },
      ],
      require.resolve('babel-plugin-transform-decorators-legacy'),
      // { ...param, completed: true }
      [
        require.resolve('babel-plugin-transform-object-rest-spread'),
        {
          useBuiltIns: true,
        },
      ],
      // Transforms JSX - Added so object-rest-spread in JSX uses builtIn
      [
        require.resolve('babel-plugin-transform-react-jsx'),
        {
          useBuiltIns: true,
        },
      ],
    ],
  };
};
if (env === 'production') {
  const prodPlugins = [
    [require.resolve('babel-plugin-transform-react-remove-prop-types'), { removeImport: true }],
    require.resolve('babel-plugin-transform-react-constant-elements'),
    require.resolve('babel-plugin-transform-react-inline-elements'),
    require.resolve('babel-plugin-transform-flow-strip-types'),
  ];

  module.exports.plugins.push(...prodPlugins);
}

if (env === 'development' || env === 'test') {
  const devPlugins = [
    // Adds component stack to warning messages
    require.resolve('babel-plugin-transform-react-jsx-source'),
    // Adds __self attribute to JSX which React will use for some warnings
    require.resolve('babel-plugin-transform-react-jsx-self'),
  ];

  module.exports.plugins.push(...devPlugins);
}
